@@ -335,6 +335,15 @@ class Reaction(object):
     """ float :
     The real rate for a given set of physical conditions.
     """
+    self.clem=None
+    """ str :
+    Something from UMIST do not know what it is.
+    """
+    self.accuracy=None
+    """ str :
+    A string describing the quality of the reactions coefficients
+    """
+
     self.comment=""
     """ str :
     Any relevant comment for this particular reaction.
@@ -601,7 +610,7 @@ class ReactionNetworkPin(ReactionNetwork):
     '''
     return (eq["reactants"] and eq["products"]) and (eq["coeffs"]==False)
 
-  def load_reactions(self,filename="Reactions.in"):
+  def load_reactions(self,filename="Reactions.in",fmt=None):
     '''
     Reads a reaction network in the format of the ProDiMo Reactions.in
 
@@ -617,9 +626,18 @@ class ReactionNetworkPin(ReactionNetwork):
 
     filename : str
       The name/path of the file to read.
+
+    fmt : str
+      Format of the file. Currently either `in` for old Reactions.in or `csv` for
+      the UMIST csv format. If `None` the routine trys to guess the format (primitive at the moment).
     '''
     # guess the format old .in or csv format
-    csv=filename.strip().endswith(".csv")
+    if fmt is None:
+      csv=filename.strip().endswith(".csv")
+    elif fmt=="csv":
+      csv=True
+    else:
+      csv=False
 
     fr=open(filename)
     self.filename=filename
@@ -637,7 +655,9 @@ class ReactionNetworkPin(ReactionNetwork):
         reac.id=int(fields[0])
         reac.idU=None
         reac.type=fields[1]
-        reac.temps=None
+        reac.clem=fields[12].strip()
+        reac.temps[:]=[float(fields[13].strip()),float(fields[14].strip())]
+        reac.accuracy=fields[15].strip()
         reac.comment=fields[16].strip()
 
         # three reactants and four products
@@ -732,6 +752,10 @@ class ReactionNetworkPin(ReactionNetwork):
     if fmt=="csv":
       for reac in self.reactions:
         fw.write("{:5d}".format(reac.id).strip())
+
+        fw.write(",")
+        fw.write(reac.type.strip())
+
         fw.write(",")
         for i in range(3):
           if i<len(reac.reactants):
@@ -756,6 +780,16 @@ class ReactionNetworkPin(ReactionNetwork):
         # assume that it is always positiv
         fw.write("{:12.4f}".format(reac.coeffs[2]).strip())
 
+        fw.write(",")
+        fw.write(reac.clem.strip())
+
+        for i in range(2):
+          fw.write(",")
+          fw.write("{:6.0f}".format(reac.temps[i]).strip())
+
+        fw.write(",")
+        fw.write(reac.accuracy.strip())
+
         fw.write(",")
         fw.write(reac.comment.strip())
 
