@@ -78,7 +78,7 @@ class CompareAbs(object):
 
     nlimfrac : float
       Relative limit of elements that are allowed to be not equal.
-      If less than `nlim *  len(aref)` elements are different the arrays
+      If less than `nlim *  len(aref)` elements are different, the arrays
       are still considered as equal.
 
     mask : mask for the array
@@ -398,7 +398,7 @@ class Compare(CompareAbs):
 
     mask=np.logical_and(mFluxes<1.e-24,mrefFluxes<1.e-24)
 
-    return self.diffArray(mFluxes,mrefFluxes,rtol=3.e-1,mask=mask)
+    return self.diffArray(mFluxes,mrefFluxes,rtol=3.e-1,nlimfrac=0.01,mask=mask)
 
   def compareSED(self):
     """
@@ -795,7 +795,7 @@ def eval_model_type(modelDir):
 
   """
 
-  if os.path.isfile(modelDir+"/ProDiMo_01.out"):
+  if os.path.isfile(modelDir+"/ProDiMo_01.out") or os.path.isfile(modelDir+"/ProDiMo_001.out"):
     mtype="prodimoTD"
 
   elif os.path.isfile(modelDir+"/Molecular_Cloud_Input.in"):
