@@ -1105,8 +1105,27 @@ class Plot(object):
             bgcolor=bgcolor,cb_format=cb_format,scalexy=[1.0,1.0],patches=patches,
             rasterized=rasterized,nolog=True,ax=ax,movie=False,returnFig=True,**kwargs)
 
-    for i in range(model.nx):
-      for j in range(model.nz-1):
+    # this is potentially very slow
+    xstart=0
+    xend=model.nx
+    ystart=0
+    yend=model.nz-1
+    if "xlim" in kwargs:
+      if kwargs["xlim"][0] is not None:
+        xstart=kwargs["xlim"][0]
+
+      if kwargs["xlim"][1] is not None:
+        xend=kwargs["xlim"][1]
+
+    if "ylim" in kwargs:
+      if kwargs["ylim"][0] is not None:
+        ystart=kwargs["ylim"][0]
+
+      if kwargs["ylim"][1] is not None:
+        yend=kwargs["ylim"][1]
+
+    for i in range(xstart,xend,1):
+      for j in range(ystart,yend,1):
         fig.axes[0].text(i,j,reacs[0][i,j],fontsize=3.0,horizontalalignment="center",verticalalignment="bottom",color="white")
 
     return fig
@@ -1734,6 +1753,9 @@ class Plot(object):
       x=np.log10(model.AVver[ix,:])
       np.seterr(**old_settings)
       zr=False
+    elif xfield=="grid":
+      x=np.range(model.nz)
+      print(x)
     else:
       x=model.z[ix,:]
 
@@ -2149,6 +2171,9 @@ class Plot(object):
     lineIdents : array_like()
       list of line identifactor of the form `[["ident",wl],["ident2",wl2]]`.
 
+    field : array_like(float,ndim=2)
+      a 2D array with numeric values for the plotting. E.g. any 2D array
+      of the :class:`~prodimopy.read.Data_ProDiMo` object.
 
     boxlinewidths : array_like
       the widths of the line for each box showing the line origin. Can be a
@@ -2696,7 +2721,11 @@ def spnToLatex(spname):
   previous_char=None
   for c in name:
     if c.isdigit():
-      newname+="_"+c
+      # case for large melecues two digits ... not nice
+      if previous_char is not None and previous_char.isdigit():
+        newname=newname[0:-2]+"_{"+previous_char+c+"}"
+      else:
+        newname+="_"+c
     # deal with ortho and para (o-, p-) species
     elif c=="-" and not (previous_char=="o" or previous_char=="p" or previous_char=="-"):
       newname+="^-"
