@@ -1077,7 +1077,11 @@ class PlotModels(object):
         x=np.log10(model.AVver[ix,:])
         np.seterr(**old_settings)
         zr=False
+      elif xfield=="grid":
+        zr=False
+        x=np.array(range(model.nz))
       else:
+        zr=False
         x=model.z[ix,:]
 
       if species==None:
@@ -1123,6 +1127,9 @@ class PlotModels(object):
     elif xfield=="tg":
       ax.set_xlabel(r"$\mathrm{\log\,T_{gas}\,[K]}$ @"+rstr)
       ax.invert_xaxis()
+    elif xfield=="grid":
+      ax.set_xlabel(r"grididx z @"+rstr)
+      ax.invert_xaxis()
     else:
       ax.set_xlabel(r"z [au] @ "+rstr)
       ax.invert_xaxis()
